<?php

$LANG = array(

#header.php
'MENU'					=> 'Menu',
'HOME'					=> 'Home',
'GOTO_CONTENT'			=> 'Do treści',
'GOTO_MENU'				=> 'Do menu',
'COMMENTS_RSS_FEEDS'	=> 'Komentarze kanału RSS',
'COMMENTS'				=> 'Komentarze',
'ARTICLES_RSS_FEEDS'	=> 'Artykuły kanału RSS',
'ARTICLES'				=> 'Artykuły',

# sidebar.php
'CATEGORIES' 			=> 'Artykuły',
'LATEST_ARTICLES'		=> 'Ostatnie artykuły',
'LATEST_COMMENTS'		=> 'Ostatnie komentarze',
'ARCHIVES'				=> 'Archiwa',

# footer.php
'POWERED_BY'			=> 'Napędza',
'PLUXML_DESCRIPTION'	=> 'Blog lub cms nie wymagający bazy danych ',
'IN'					=> 'w czasie',
'ADMINISTRATION'		=> 'Administracja',
'GOTO_TOP'				=> 'Przejdź do góry',
'TOP'					=> 'Top',

# erreur.php
'ERROR'					=> 'Błąd',
'BACKTO_HOME'			=> 'Przejdź do strony głównej',

# common
'WRITTEN_BY'			=> 'Napisał',
'CLASSIFIED_IN'			=> 'Sklasyfikowane w',
'TAGS'					=> 'Tagi',

# commentaires.php
'SAID'					=> 'rzekł',
'WRITE_A_COMMENT'		=> 'Napisz komentarz',
'NAME'					=> 'Imię',
'WEBSITE'				=> 'Strona (opcjonalne)',
'EMAIL'					=> 'E-mail (opcjonalne)',
'COMMENT'				=> 'Komentarz',
'CLEAR'					=> 'Wyczyść',
'SEND'					=> 'Wyślij',
'COMMENTS_CLOSED'		=> 'Komentarze zostały wyłączone',
'ANTISPAM_WARNING'		=> 'Kontrola anty-spam',

'REPLY'					=> 'Odpowiedź',
'REPLY_TO'				=> 'Odpowiedź',
'CANCEL'				=> 'Anulować',


);

?>